@@ -1,4 +1,4 @@
-//! Peripheral access API for STM32F2 microcontrollers
+//! Peripheral access API for STM32F3 microcontrollers
 //! (generated using [svd2rust](https://github.com/rust-embedded/svd2rust)
 //! 0.19.0)
 //!
@@ -8,9 +8,9 @@
 //! For more details see the README here:
 //! [stm32-rs](https://github.com/stm32-rs/stm32-rs)
 //!
-//! This crate supports all STM32F2 devices; for the complete list please
+//! This crate supports all STM32F3 devices; for the complete list please
 //! see:
-//! [stm32f2](https://crates.io/crates/stm32f2)
+//! [stm32f3](https://crates.io/crates/stm32f3)
 //!
 //! Due to doc build limitations, not all devices may be shown on docs.rs;
 //! a representative few have been selected instead. For a complete list of
@@ -23,9 +23,18 @@
 mod generic;
 pub use self::generic::*;
 
-#[cfg(feature = "stm32f215")]
-pub mod stm32f215;
+#[cfg(feature = "stm32f301")]
+pub mod stm32f301;
 
-#[cfg(feature = "stm32f217")]
-pub mod stm32f217;
+#[cfg(feature = "stm32f302")]
+pub mod stm32f302;
+
+#[cfg(feature = "stm32f303")]
+pub mod stm32f303;
+
+#[cfg(feature = "stm32f373")]
+pub mod stm32f373;
+
+#[cfg(feature = "stm32f3x4")]
+pub mod stm32f3x4;
 
